<?php

namespace Drupal\push_notification\Form;

/**
 * @file
 * Provides push_notification functionality.
 */

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\push_notification\Controller\PushNotificationController;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\user\Entity\User;
use Drupal\user\Entity\Role;

/**
 * Implements the youtube subscriber button form controller.
 *
 * @see \Drupal\Core\Form\FormBase
 * @see \Drupal\Core\Form\ConfigFormBase
 */
class PushNotificationForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'push_notification_form';
  }

  /**
   * {@inheritdoc}
   */
   public function buildForm(array $form, FormStateInterface $form_state) {

   		$roles_obj = Role::loadMultiple();
   		$user_roles = array_combine(array_keys($roles_obj), array_map(function($a){ return $a->label();}, $roles_obj));
   		unset($user_roles['anonymous']);

   		$form['user_roles'] = array(
	      '#type' => 'select',
	  	  '#multiple' => TRUE,
		  '#title' => t('Select User Roles'),
		  '#required' => FALSE,
		  '#options' => $user_roles,
	      '#size' => 10,
	        '#weight' => 0,
	      '#attributes' => array('id' => 'push_notification_user_roles', 'class' => 'chosen-select',),
  		);

		$form['push_notification_title'] = array(
		  '#type' => 'textfield',
		  '#title' => t('Title'),
		  '#required' => TRUE,
		);

		$form['push_notification_message'] = array(
		  '#type' => 'textarea',
		  '#title' => t('Message'),
		  '#required' => TRUE,
		);

		$form['submit'] = array(
		  '#type' => 'submit',
		  '#value' => t('Push Notify'),
		);

		return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

	//Stores Submitted Values into variables
	$push_notify_title = $form_state->getValue('push_notification_title');
	$push_notify_message = $form_state->getValue('push_notification_message');
	$user_roles = $form_state->getValue('user_roles');

	$ids = '';
	if( !empty($user_roles) ) {
		$ids = \Drupal::entityQuery('user')
		->condition('status', 1)
		->condition('roles', $user_roles, 'IN')
		->execute();
	}
	else {
		$ids = \Drupal::entityQuery('user')
		->condition('status', 1)
		->execute();
	}

	$users = User::loadMultiple($ids);

	foreach($users as $user_array){
		$device_token = trim($user_array->get('field_device_token')->value);

		/*This will sent Unlimited Notifications to Customers via Admin */
		$send_notification = PushNotificationController::sendPushNotifications($device_token, $push_notify_title, $push_notify_message);

		if($send_notification) {
			drupal_set_message(t('Push Notifications has been sent successfully to the Users!'), 'status', TRUE);
		}
		else {
			drupal_set_message(t('Error while sending Push Notifications! Please try again Later!'), 'error', TRUE);
		}

		return new RedirectResponse(\Drupal\Core\Url::fromRoute('push_notification.push_notify_form')->toString());
	}
  }
}
